;; Generated package description from math-symbol-lists.el  -*- no-byte-compile: t -*-
(define-package "math-symbol-lists" "1.3.0.20220828.204754" "Lists of Unicode math symbols and latex commands" 'nil :commit "ac3eb053d3b576fcdd192b0ac6ad5090ea3a7079" :authors '(("Vitalie Spinu" . "spinuvit@gmail.com")) :maintainer '("Vitalie Spinu" . "spinuvit@gmail.com") :keywords '("unicode" "symbols" "mathematics") :url "https://github.com/vspinu/math-symbol-lists")
